==> theme-customizer_0.9-21.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Finnish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings...</source>
        <translation>Ladataan asetuksia...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings</source>
        <translation>Asetusten lataus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Ok, thanks.</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Overwrite color preset?</source>
        <translation>Ylikirjoitetaanko väripresetti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>Tällä nimellä on jo tallennettu väripresetti, ylikirjoitetaanko?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete color preset?</source>
        <translation>Poistetaanko väripresetti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this preset?</source>
        <translation>Oletko varma että haluat poistaa väripresetin?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color presets</source>
        <translation>Väripresetit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Save color preset</source>
        <translation>Tallenna presetti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Fontin koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>OLETUS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Fontin värit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Toissijainen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Aktiivinen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Disabloitu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Maalattu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation>Painike</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation>Painike painettu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Maalauksen väri</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Ikonien teema</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Näytä pikakuvakkeiden tausta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Snap-to-grid koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity</source>
        <translation>Widgettien näkyvyys</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Pikakuvakkeiden koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Kirjanmerkkien koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Uudelleenkäynnistys</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Käynnistä uudelleen automaattisesti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Hyväksy muutokset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from MyDocs</source>
        <translation>Tuo fontteja MyDocs:sta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation>Tuo kaikki fontit MyDocs -kansiosta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Change backgrounds</source>
        <translation>Vaihda taustoja</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Käsitellään teemaa...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Etsitään ja tuodaan fontteja...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation>Tallenna ja uudelleenkäynnistä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - fonttien tuonti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Haluatko tuoda fontteja MyDocs -kansiosta?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Huom: Tämä toiminto etsii ja tuo fontit ainaostaan MyDocs -kansion juuresta</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Fonttien tuonti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation>Tietoja Theme Customizerista</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Clock</source>
        <translation>Kello</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>App Manager</source>
        <translation>Sov. hallinta</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Media Player</source>
        <translation>Mediasoitin</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Lockscreen</source>
        <translation>Lukitusruutu</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Tap me to change</source>
        <translation>Kosketa vaihtaaksesi</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Set image</source>
        <translation>Aseta kuva</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Backgrounds</source>
        <translation>Taustakuvat</translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset as...</source>
        <translation>Tallena väripresetti nimellä...</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset</source>
        <translation>Tallenna väripresetti</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Choose color preset:</source>
        <translation>Valitse presetti:</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Currently active colors</source>
        <translation>Nykyiset aktiiviset värit</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Load</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Manage color presets</source>
        <translation>Hallitse väripresettejä</translation>
    </message>
</context>
</TS>

==> theme-customizer_0.9-22.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Finnish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings...</source>
        <translation>Ladataan asetuksia...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings</source>
        <translation>Asetusten lataus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Ok, thanks.</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Overwrite color preset?</source>
        <translation>Ylikirjoitetaanko väripresetti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>Tällä nimellä on jo tallennettu väripresetti, ylikirjoitetaanko?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete color preset?</source>
        <translation>Poistetaanko väripresetti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this preset?</source>
        <translation>Oletko varma että haluat poistaa väripresetin?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color presets</source>
        <translation>Väripresetit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Save color preset</source>
        <translation>Tallenna presetti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Fontin koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>OLETUS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Fontin värit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Toissijainen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Aktiivinen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Disabloitu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Maalattu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation>Painike</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation>Painike painettu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Maalauksen väri</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Ikonien teema</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Näytä pikakuvakkeiden tausta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Snap-to-grid koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity</source>
        <translation>Widgettien näkyvyys</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Pikakuvakkeiden koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Kirjanmerkkien koko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Uudelleenkäynnistys</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Käynnistä uudelleen automaattisesti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Hyväksy muutokset</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from MyDocs</source>
        <translation>Tuo fontteja MyDocs:sta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation>Tuo kaikki fontit MyDocs -kansiosta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Change backgrounds</source>
        <translation>Vaihda taustoja</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Käsitellään teemaa...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Etsitään ja tuodaan fontteja...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation>Tallenna ja uudelleenkäynnistä</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - fonttien tuonti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Haluatko tuoda fontteja MyDocs -kansiosta?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Huom: Tämä toiminto etsii ja tuo fontit ainaostaan MyDocs -kansion juuresta</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Fonttien tuonti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation>Tietoja Theme Customizerista</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Clock</source>
        <translation>Kello</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>App Manager</source>
        <translation>Sov. hallinta</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Media Player</source>
        <translation>Mediasoitin</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Lockscreen</source>
        <translation>Lukitusruutu</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Tap me to change</source>
        <translation>Kosketa vaihtaaksesi</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Set image</source>
        <translation>Aseta kuva</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Backgrounds</source>
        <translation>Taustakuvat</translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset as...</source>
        <translation>Tallena väripresetti nimellä...</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset</source>
        <translation>Tallenna väripresetti</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Choose color preset:</source>
        <translation>Valitse presetti:</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Currently active colors</source>
        <translation>Nykyiset aktiiviset värit</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Load</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Manage color presets</source>
        <translation>Hallitse väripresettejä</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Original colors of current theme</source>
        <translation>Nykyisen teeman alkuperäiset värit</translation>
    </message>
</context>
</TS>
